@@ -35,8 +35,7 @@ dls = DLStudio(
                   learning_rate = 1e-3,
                   epochs = 2,
                   batch_size = 4,
-                  classes = ('plane','car','bird','cat','deer',
-                             'dog','frog','horse','ship','truck'),
+                  classes = ('plane','car','bird','cat','deer','dog','frog','horse','ship','truck'),
                   use_gpu = True,
               )
 
