@@ -45,11 +45,8 @@ dls = DLStudio(
                   learning_rate = 1e-3,
                   epochs = 2,
                   batch_size = 4,
-                  classes = ('plane','car','bird','cat','deer',
-                             'dog','frog','horse','ship','truck'),
+                  classes = ('plane','car','bird','cat','deer','dog','frog','horse','ship','truck'),
                   use_gpu = True,
-                  debug_train = 0,
-                  debug_test = 1,
               )
 
 configs_for_all_convo_layers = dls.parse_config_string_for_convo_layers()
@@ -59,10 +56,10 @@ fc_layers = dls.build_fc_layers()
 model = dls.Net(convo_layers, fc_layers)
 
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
-print("\n\nThe number of learnable parameters in the model: %d\n\n" % number_of_learnable_params)
+print("\n\nThe number of learnable parameters in the model: %d\n" % number_of_learnable_params)
 
 num_layers = len(list(model.parameters()))
-print("\n\nThe number of layers in the model: %d\n\n" % num_layers)
+print("\nThe number of layers in the model: %d\n" % num_layers)
 
 dls.load_cifar_10_dataset()
 dls.run_code_for_training(model)
